==> pythran-0.4.0.tar.gz: pythran-0.4.0/pythran/nt2/sdk/config/type_lists.hpp <==
/*******************************************************************************
 *         Copyright 2003-2010 LASMEA UMR 6602 CNRS/U.B.P
 *         Copyright 2009-2010 LRI    UMR 8623 CNRS/Univ Paris Sud XI
 *
 *          Distributed under the Boost Software License, Version 1.0.
 *                 See accompanying file LICENSE.txt or copy at
 *                     http://www.boost.org/LICENSE_1_0.txt
 ******************************************************************************/

#ifndef NT2_SDK_CONFIG_TYPE_LISTS_HPP_INCLUDED
#define NT2_SDK_CONFIG_TYPE_LISTS_HPP_INCLUDED

#include <boost/simd/sdk/simd/extensions.hpp>

#define NT2_TYPES BOOST_SIMD_TYPES
#define NT2_REAL_TYPES BOOST_SIMD_REAL_TYPES
#define NT2_REAL_CONVERTIBLE_TYPES BOOST_SIMD_REAL_CONVERTIBLE_TYPES
#define NT2_UNSIGNED_TYPES BOOST_SIMD_UNSIGNED_TYPES
#define NT2_SIGNED_TYPES BOOST_SIMD_SIGNED_TYPES
#define NT2_INTEGRAL_TYPES BOOST_SIMD_INTEGRAL_TYPES
#define NT2_INTEGRAL_SIGNED_TYPES BOOST_SIMD_INTEGRAL_SIGNED_TYPES
#define NT2_INT_CONVERT_TYPES BOOST_SIMD_INT_CONVERT_TYPES
#define NT2_UINT_CONVERT_TYPES BOOST_SIMD_UINT_CONVERT_TYPES
#define NT2_SIGNED_INT_GT_8 BOOST_SIMD_SIGNED_INT_GT_8
#define NT2_UNSIGNED_INT_GT_8 BOOST_SIMD_UNSIGNED_INT_GT_8
#define NT2_INT_64_TYPES BOOST_SIMD_INT_64_TYPES
#define NT2_INT_32_TYPES BOOST_SIMD_INT_32_TYPES
#define NT2_INT_16_TYPES BOOST_SIMD_INT_16_TYPES
#define NT2_INT_8_TYPES BOOST_SIMD_INT_8_TYPES
#define NT2_GROUPABLE_TYPES BOOST_SIMD_GROUPABLE_TYPES
#define NT2_SPLITABLE_TYPES BOOST_SIMD_SPLITABLE_TYPES
#define NT2_INT_GT8_TYPES BOOST_SIMD_INT_GT8_TYPES
#define NT2_SIGNED_INT_GT_8_TYPES BOOST_SIMD_SIGNED_INT_GT_8_TYPES
#define NT2_UNSIGNED_INT_GT_8_TYPES BOOST_SIMD_UNSIGNED_INT_GT_8_TYPES
#define NT2_LT64_TYPES BOOST_SIMD_LT64_TYPES
#define NT2_GT16_TYPES BOOST_SIMD_T16_TYPES
#define NT2_SIGNED_INT_GT_16_TYPES BOOST_SIMD_SIGNED_INT_GT_16_TYPES
#define NT2_UNSIGNED_INT_GT_16_TYPES BOOST_SIMD_UNSIGNED_INT_GT_16_TYPES

#define NT2_SIMD_TYPES BOOST_SIMD_SIMD_TYPES
#define NT2_SIMD_REAL_TYPES BOOST_SIMD_SIMD_REAL_TYPES
#define NT2_SIMD_REAL_CONVERTIBLE_TYPES BOOST_SIMD_SIMD_REAL_CONVERTIBLE_TYPES
#define NT2_SIMD_UNSIGNED_TYPES BOOST_SIMD_SIMD_UNSIGNED_TYPES
#define NT2_SIMD_SIGNED_TYPES BOOST_SIMD_SIMD_SIGNED_TYPES
#define NT2_SIMD_INTEGRAL_TYPES BOOST_SIMD_SIMD_INTEGRAL_TYPES
#define NT2_SIMD_INTEGRAL_SIGNED_TYPES BOOST_SIMD_SIMD_INTEGRAL_SIGNED_TYPES
#define NT2_SIMD_INT_CONVERT_TYPES BOOST_SIMD_SIMD_INT_CONVERT_TYPES
#define NT2_SIMD_UINT_CONVERT_TYPES BOOST_SIMD_SIMD_UINT_CONVERT_TYPES
#define NT2_SIMD_SIGNED_INT_GT_8 BOOST_SIMD_SIMD_SIGNED_INT_GT_8
#define NT2_SIMD_UNSIGNED_INT_GT_8 BOOST_SIMD_SIMD_UNSIGNED_INT_GT_8
#define NT2_SIMD_INT_64_TYPES BOOST_SIMD_SIMD_INT_64_TYPES
#define NT2_SIMD_INT_32_TYPES BOOST_SIMD_SIMD_INT_32_TYPES
#define NT2_SIMD_INT_16_TYPES BOOST_SIMD_SIMD_INT_16_TYPES
#define NT2_SIMD_INT_8_TYPES BOOST_SIMD_SIMD_INT_8_TYPES
#define NT2_SIMD_GROUPABLE_TYPES BOOST_SIMD_SIMD_GROUPABLE_TYPES
#define NT2_SIMD_SPLITABLE_TYPES BOOST_SIMD_SIMD_SPLITABLE_TYPES
#define NT2_SIMD_INT_GT8_TYPES BOOST_SIMD_SIMD_INT_GT8_TYPES
#define NT2_SIMD_SIGNED_INT_GT_8_TYPES BOOST_SIMD_SIMD_SIGNED_INT_GT_8_TYPES
#define NT2_SIMD_UNSIGNED_INT_GT_8_TYPES BOOST_SIMD_SIMD_UNSIGNED_INT_GT_8_TYPES
#define NT2_SIMD_LT64_TYPES BOOST_SIMD_SIMD_LT64_TYPES
#define NT2_SIMD_GT16_TYPES BOOST_SIMD_SIMD_GT16_TYPES
#define NT2_SIMD_SIGNED_INT_GT_16_TYPES BOOST_SIMD_SIMD_SIGNED_INT_GT_16_TYPES
#define NT2_SIMD_UNSIGNED_INT_GT_16_TYPES BOOST_SIMD_SIMD_UNSIGNED_INT_GT_16_TYPES

#define NT2_SIMD_DEFAULT_EXTENSION BOOST_SIMD_DEFAULT_EXTENSION

#endif

==> pythran-0.6.0.tar.gz: pythran-0.6.0/pythran/nt2/sdk/config/type_lists.hpp <==
//==============================================================================
//         Copyright 2003 - 2012   LASMEA UMR 6602 CNRS/Univ. Clermont II
//         Copyright 2009 - 2012   LRI    UMR 8623 CNRS/Univ Paris Sud XI
//
//          Distributed under the Boost Software License, Version 1.0.
//                 See accompanying file LICENSE.txt or copy at
//                     http://www.boost.org/LICENSE_1_0.txt
//==============================================================================
#ifndef NT2_SDK_CONFIG_TYPE_LISTS_HPP_INCLUDED
#define NT2_SDK_CONFIG_TYPE_LISTS_HPP_INCLUDED

#include <boost/simd/sdk/simd/extensions.hpp>
#include <boost/simd/sdk/config/type_lists.hpp>

#define NT2_TYPES BOOST_SIMD_TYPES
#define NT2_REAL_TYPES BOOST_SIMD_REAL_TYPES
#define NT2_REAL_CONVERTIBLE_TYPES BOOST_SIMD_REAL_CONVERTIBLE_TYPES
#define NT2_UNSIGNED_TYPES BOOST_SIMD_UNSIGNED_TYPES
#define NT2_SIGNED_TYPES BOOST_SIMD_SIGNED_TYPES
#define NT2_INTEGRAL_TYPES BOOST_SIMD_INTEGRAL_TYPES
#define NT2_INTEGRAL_SIGNED_TYPES BOOST_SIMD_INTEGRAL_SIGNED_TYPES
#define NT2_INTEGRAL_UNSIGNED_TYPES BOOST_SIMD_INTEGRAL_UNSIGNED_TYPES
#define NT2_INT_CONVERT_TYPES BOOST_SIMD_INT_CONVERT_TYPES
#define NT2_UINT_CONVERT_TYPES BOOST_SIMD_UINT_CONVERT_TYPES
#define NT2_GROUPABLE_TYPES BOOST_SIMD_GROUPABLE_TYPES
#define NT2_SPLITABLE_TYPES BOOST_SIMD_SPLITABLE_TYPES
#define NT2_REAL_GROUPABLE_TYPES BOOST_SIMD_REAL_GROUPABLE_TYPES
#define NT2_REAL_SPLITABLE_TYPES BOOST_SIMD_REAL_SPLITABLE_TYPES

#define NT2_SIMD_TYPES BOOST_SIMD_SIMD_TYPES
#define NT2_SIMD_REAL_TYPES BOOST_SIMD_SIMD_REAL_TYPES
#define NT2_SIMD_REAL_CONVERTIBLE_TYPES BOOST_SIMD_SIMD_REAL_CONVERTIBLE_TYPES
#define NT2_SIMD_UNSIGNED_TYPES BOOST_SIMD_SIMD_UNSIGNED_TYPES
#define NT2_SIMD_SIGNED_TYPES BOOST_SIMD_SIMD_SIGNED_TYPES
#define NT2_SIMD_INTEGRAL_TYPES BOOST_SIMD_SIMD_INTEGRAL_TYPES
#define NT2_SIMD_INTEGRAL_SIGNED_TYPES BOOST_SIMD_SIMD_INTEGRAL_SIGNED_TYPES
#define NT2_SIMD_INTEGRAL_UNSIGNED_TYPES BOOST_SIMD_SIMD_INTEGRAL_UNSIGNED_TYPES
#define NT2_SIMD_INT_CONVERT_TYPES BOOST_SIMD_SIMD_INT_CONVERT_TYPES
#define NT2_SIMD_UINT_CONVERT_TYPES BOOST_SIMD_SIMD_UINT_CONVERT_TYPES
#define NT2_SIMD_GROUPABLE_TYPES BOOST_SIMD_SIMD_GROUPABLE_TYPES
#define NT2_SIMD_SPLITABLE_TYPES BOOST_SIMD_SIMD_SPLITABLE_TYPES
#define NT2_SIMD_REAL_GROUPABLE_TYPES BOOST_SIMD_SIMD_REAL_GROUPABLE_TYPES
#define NT2_SIMD_REAL_SPLITABLE_TYPES BOOST_SIMD_SIMD_REAL_SPLITABLE_TYPES

#define NT2_SIMD_DEFAULT_EXTENSION BOOST_SIMD_DEFAULT_EXTENSION

#endif
